@@ -251,8 +251,14 @@ class CurtailWindow(Adw.ApplicationWindow):
         if new_file is None:
             new_file = self._settings.get_boolean('new-file')
         if new_file:
-            label = _("Safe mode with '{}' suffix")\
-                                 .format(self._settings.get_string('suffix'))
+            suffix_prefix = self._settings.get_string('suffix-prefix')
+
+            if self._settings.get_int('naming-mode') == 0:
+                label = _(f"Safe mode with “{suffix_prefix}” suffix")\
+                        .format(suffix_prefix)
+            else:
+                label = _(f"Safe mode with “{suffix_prefix}” prefix")\
+                        .format(suffix_prefix)
         else:
             label = _("Overwrite mode")
         self.window_title.set_subtitle(label)
@@ -372,11 +378,19 @@ class CurtailWindow(Adw.ApplicationWindow):
             return False
 
     def create_new_filename(self, path):
+        parent = path.parents[0]
+        stem = path.stem
+        suffix_prefix = self._settings.get_string('suffix-prefix')
+        extension = path.suffix
+
         # Use new file or not
         if self._settings.get_boolean('new-file'):
-            new_filename = '{}/{}{}{}'.format(path.parents[0],
-                path.stem, self._settings.get_string('suffix'),
-                path.suffix)
+            if self._settings.get_int('naming-mode') == 0: # Suffix selected
+                new_filename = f'{parent}/{stem}{suffix_prefix}{extension}'\
+                    .format(parent, stem, suffix_prefix, extension)
+            else: # Prefix selected
+                new_filename = f'{parent}/{suffix_prefix}{stem}{extension}'\
+                    .format(parent, suffix_prefix, stem, extension)
         else :
             new_filename = str(path)
         return new_filename
@@ -399,9 +413,12 @@ class CurtailWindow(Adw.ApplicationWindow):
                 error_message = _("This file doesn't exist.").format(filename)
 
             # Check format
-            size = path.stat().st_size
-            if not self.check_format(filename) or size <= 0:
-                error_message = _("Format of this file is not supported.").format(path.name)
+            if not error_message:
+                size = path.stat().st_size
+                if not self.check_format(filename) or size <= 0:
+                    error_message = _("Format of this file is not supported.").format(path.name)
+            else:
+                size = 0
 
             if not error_message:
                 new_filename = self.create_new_filename(path)
@@ -427,8 +444,8 @@ class CurtailWindow(Adw.ApplicationWindow):
         compressor = Compressor(result_items, self.update_result_item, self.enable_compression)
         GLib.idle_add(compressor.compress_images)
 
-    def on_lossy_changed(self, switch, state):
-        self._settings.set_boolean('lossy', switch.get_active())
+    def on_lossy_changed(self, toggle, state):
+        self._settings.set_boolean("lossy", toggle.get_active_name() == "lossy")
 
     def banner_change_mode(self, *args):
         self._settings.set_boolean('new-file', True)
@@ -449,7 +466,7 @@ class CurtailWindow(Adw.ApplicationWindow):
                     license_type=Gtk.License.GPL_3_0,
                     website='https://github.com/Huluti/Curtail',
                     issue_url='https://github.com/Huluti/Curtail/issues/new',
-                    version='1.12.0',
+                    version='1.13.0',
                     developers=[
                         'Hugo Posnic https://github.com/Huluti'
                     ],
